"use strict";

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _chai = _interopRequireWildcard(require("chai"));

var _chaiEnzyme = _interopRequireDefault(require("chai-enzyme"));

var _icon = _interopRequireDefault(require("../../icon"));

var _iconSettings = _interopRequireDefault(require("../../icon-settings"));

var _pageHeader = _interopRequireDefault(require("../../page-header"));

var _control = _interopRequireDefault(require("../../page-header/control"));

var _buttonStateful = _interopRequireDefault(require("../../button-stateful"));

var _buttonGroup = _interopRequireDefault(require("../../button-group"));

var _button = _interopRequireDefault(require("../../button"));

var _menuDropdown = _interopRequireDefault(require("../../menu-dropdown"));

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

_chai.default.use((0, _chaiEnzyme.default)());

var recordHomeActions = function recordHomeActions() {
  return _react.default.createElement(_react.default.Fragment, null, _react.default.createElement(_control.default, null, _react.default.createElement(_buttonStateful.default, {
    key: "PageHeaderFollowButton",
    disabled: false,
    iconSize: "medium",
    responsive: false,
    stateOne: {
      iconCategory: 'utility',
      iconName: 'add',
      label: 'Follow'
    },
    stateTwo: {
      iconCategory: 'utility',
      iconName: 'check',
      label: 'Following'
    },
    stateThree: {
      iconCategory: 'utility',
      iconName: 'close',
      label: 'Unfollow'
    }
  })), _react.default.createElement(_control.default, null, _react.default.createElement(_buttonGroup.default, {
    variant: "list"
  }, _react.default.createElement(_button.default, {
    label: "Edit"
  }), _react.default.createElement(_button.default, {
    label: "Delete"
  }), _react.default.createElement(_button.default, {
    label: "Clone"
  }), _react.default.createElement(_menuDropdown.default, {
    assistiveText: {
      icon: 'More Options'
    },
    buttonVariant: "icon",
    iconCategory: "utility",
    iconName: "down",
    iconVariant: "border-filled",
    onSelect: function onSelect() {
      console.log('selected');
    },
    openOn: "click",
    align: "right",
    options: [{
      label: 'Disable',
      value: 'A0'
    }, {
      label: 'Promote',
      value: 'C0'
    }]
  }))));
};

var recordHomeDetails = [{
  label: 'Description',
  content: 'Description that demonstrates truncation with content. Description that demonstrates truncation with content.',
  flavor: '1-of-4',
  truncate: true
}, {
  label: 'Last Modified',
  content: 'August 31, 2016 2:01PM PST'
}, {
  label: 'Status',
  content: 'Status of thing you wanna know'
}];
describe('PageHeader: ', function () {
  var defaultPropsRecordHome = {
    icon: _react.default.createElement(_icon.default, {
      assistiveText: {
        label: 'User'
      },
      category: "standard",
      name: "user"
    }),
    label: 'Record Type',
    title: 'Record Title',
    variant: 'record-home',
    onRenderActions: recordHomeActions,
    details: recordHomeDetails
  };
  describe('Renders basic props', function () {
    it('renders correct Icon prop', function () {
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_iconSettings.default, {
        iconPath: "/assets/icons"
      }, _react.default.createElement(_pageHeader.default, defaultPropsRecordHome)));
      var svg = wrapper.find('.slds-media__figure .slds-icon-standard-user');
      (0, _chai.expect)(svg).to.exist;
    });
    it('renders correct Label prop', function () {
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_iconSettings.default, {
        iconPath: "/assets/icons"
      }, _react.default.createElement(_pageHeader.default, defaultPropsRecordHome)));
      (0, _chai.expect)(wrapper.find('SLDSPageHeader')).to.have.prop('label', 'Record Type');
    });
    it('renders correct Title prop', function () {
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_iconSettings.default, {
        iconPath: "/assets/icons"
      }, _react.default.createElement(_pageHeader.default, defaultPropsRecordHome)));
      (0, _chai.expect)(wrapper.find('SLDSPageHeader')).to.have.prop('title', 'Record Title');
    });
    it('renders onRenderActions prop', function () {
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_iconSettings.default, {
        iconPath: "/assets/icons"
      }, _react.default.createElement(_pageHeader.default, defaultPropsRecordHome)));
      var statefulBtn = wrapper.find('.slds-not-selected');
      var buttonGroup = wrapper.find('.slds-button-group-list');
      (0, _chai.expect)(statefulBtn).to.have.length(1);
      (0, _chai.expect)(buttonGroup).to.have.length(1);
    });
    it('renders Fields prop', function () {
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_iconSettings.default, {
        iconPath: "/assets/icons"
      }, _react.default.createElement(_pageHeader.default, defaultPropsRecordHome)));
      var field1 = wrapper.find('.slds-page-header__detail-block').first();
      (0, _chai.expect)(field1.find('.slds-text-title').text()).to.equal('Description');
      (0, _chai.expect)(field1.find('.slds-truncate').last().text()).to.equal('Description that demonstrates truncation with content. Description that demonstrates truncation with content.');
    });
  });
  describe('Truncation works in all the ways Donielle can think of', function () {
    it('field content truncates if this.props.truncate is true', function () {
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_iconSettings.default, {
        iconPath: "/assets/icons"
      }, _react.default.createElement(_pageHeader.default, defaultPropsRecordHome)));
      var field1 = wrapper.find('.slds-page-header__detail-block').first();
      var field1Content = field1.find('.slds-truncate').last();
      (0, _chai.expect)(field1Content.hasClass('slds-truncate')).to.equal(true);
    });
  });
});