"use strict";

var _react = _interopRequireDefault(require("react"));

var _reactDom = _interopRequireDefault(require("react-dom"));

var _lodash = _interopRequireDefault(require("lodash.assign"));

var _chai = require("chai");

var _iconSettings = _interopRequireDefault(require("../../icon-settings"));

var _button = _interopRequireDefault(require("../../button"));

var _settings = _interopRequireDefault(require("../../settings"));

var _checkbox = _interopRequireDefault(require("../../checkbox"));

var _welcomeMat = _interopRequireDefault(require("../../welcome-mat"));

var _tile = _interopRequireDefault(require("../../welcome-mat/tile"));

var _infoBadge = _interopRequireDefault(require("../../welcome-mat/info-badge"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// import TestUtils from 'react-dom/test-utils';
// const { Simulate } = TestUtils;
describe('SLDSWelcomeMat: ', function () {
  var container;
  var renderedNode; // set "app node" fixture, so no warnings are triggered.

  var appNode = document.createElement('span');
  appNode.id = 'app';
  document.body.appendChild(appNode);

  _settings.default.setAppElement('#app');

  after(function () {
    document.body.removeChild(appNode);
    appNode = null;
  });
  afterEach(function () {
    _reactDom.default.unmountComponentAtNode(container);

    document.body.removeChild(container);
    container = null;
  });

  var renderWelcomeMat = function renderWelcomeMat(welcomeMatInstance) {
    container = document.createElement('div');

    var opener = _react.default.createElement(_iconSettings.default, {
      iconPath: "/assets/icons"
    }, welcomeMatInstance);

    document.body.appendChild(container);
    renderedNode = _reactDom.default.hydrate(opener, container);
    return renderedNode;
  };

  var title = 'The Lightning Experience is here!';
  var description = 'This is a sample description for the welcome mat';
  var labels = {
    title: title,
    description: description
  };
  var defaultProps = {
    isOpen: true,
    labels: labels
  };

  var createWelcomeMat = function createWelcomeMat(props) {
    return _react.default.createElement(_welcomeMat.default, (0, _lodash.default)({}, defaultProps, props));
  };

  var getWelcomeMat = function getWelcomeMat(props) {
    return renderWelcomeMat(createWelcomeMat(props));
  };

  var getWelcomeMatNode = function getWelcomeMatNode(dom) {
    return dom.querySelector('.slds-modal');
  };

  var tiles = [_react.default.createElement(_tile.default, {
    title: "Welcome to Salesforce!",
    description: "Lorem ipsum dolor sit amet, lorem ipsum dolor sit amet.",
    icon: "animal_and_nature",
    href: "javascript:void(0);",
    isComplete: true
  }), _react.default.createElement(_tile.default, {
    title: "Learn About OpenCTI!",
    description: "Lorem ipsum dolor sit amet, lorem ipsum dolor sit amet.",
    icon: "call",
    href: "javascript:void(0);",
    isComplete: true
  }), _react.default.createElement(_tile.default, {
    title: "Power Up the Utility Bar",
    description: "Tap into case history or share notes with fellow agents\u2014it all happens on the utility bar.",
    href: "javascript:void(0);",
    icon: "call"
  }), _react.default.createElement(_tile.default, {
    title: "Customize your view",
    description: "Tailor your cases to your team's workflow with custom list views.",
    href: "javascript:void(0);",
    icon: "upload"
  }), _react.default.createElement(_tile.default, {
    title: "Share the Knowledge",
    description: "Harness your team's collective know-how with our powerful knowledge base.",
    href: "javascript:void(0);",
    icon: "knowledge_base"
  })];
  describe('Steps Variant', function () {
    beforeEach(function () {
      getWelcomeMat({
        variant: 'steps',
        labels: labels,
        children: tiles,
        id: 'welcome-mat-test'
      });
    });
    it('renders welcome mat', function () {
      var WelcomeMatContainer = getWelcomeMatNode(document.body).querySelector('.slds-welcome-mat');
      (0, _chai.expect)(WelcomeMatContainer).to.exist;
      (0, _chai.expect)(WelcomeMatContainer.querySelector('.slds-welcome-mat__content')).to.exist;
      (0, _chai.expect)(WelcomeMatContainer.querySelector('.slds-welcome-mat__info')).to.exist;
      (0, _chai.expect)(WelcomeMatContainer.querySelector('.slds-welcome-mat__tiles')).to.exist;
      (0, _chai.expect)(WelcomeMatContainer.querySelector('.slds-welcome-mat__tiles').childElementCount).to.eql(5);
      (0, _chai.expect)(WelcomeMatContainer.querySelectorAll('.slds-welcome-mat__tile_complete').length).to.eql(2);
    });
    it('tile links have correct href', function () {
      var WelcomeMatTiles = getWelcomeMatNode(document.body).querySelectorAll('.slds-welcome-mat__tile a');
      WelcomeMatTiles.forEach(function (tile) {
        (0, _chai.expect)(tile.href).to.eql.toString('javascript:void(0)');
      });
    });
    it('shows labels correctly', function () {
      var WelcomeMatInfo = getWelcomeMatNode(document.body).querySelector('.slds-welcome-mat__info');
      (0, _chai.expect)(WelcomeMatInfo.querySelector('.slds-welcome-mat__info-title').textContent).to.eql(title);
      (0, _chai.expect)(WelcomeMatInfo.querySelector('.slds-welcome-mat__info-description').textContent).to.eql(description);
      (0, _chai.expect)(WelcomeMatInfo.querySelector('.slds-welcome-mat__info-progress p').textContent).to.eql('2/5 units completed');
    });
  });
  describe('Info-Only Variant', function () {
    beforeEach(function () {
      getWelcomeMat({
        variant: 'info-only',
        labels: labels,
        id: 'welcome-mat-test',
        children: tiles,
        doNotShowAgainCheckbox: _react.default.createElement(_checkbox.default, {
          assistiveText: {
            label: "Don't show this again"
          },
          labels: {
            label: "Don't show this again"
          }
        }),
        onRenderInfoActions: function onRenderInfoActions() {
          return _react.default.createElement(_button.default, {
            type: "button",
            variant: "brand",
            title: "Learn More",
            label: "Learn More"
          });
        }
      });
    });
    it('renders welcome mat', function () {
      var WelcomeMatContainer = getWelcomeMatNode(document.body).querySelector('.slds-welcome-mat');
      (0, _chai.expect)(WelcomeMatContainer).to.exist;
      (0, _chai.expect)(WelcomeMatContainer.querySelector('.slds-welcome-mat__content')).to.exist;
      (0, _chai.expect)(WelcomeMatContainer.querySelector('.slds-welcome-mat__info')).to.exist;
      (0, _chai.expect)(WelcomeMatContainer.querySelector('.slds-welcome-mat__tiles')).to.exist;
      (0, _chai.expect)(WelcomeMatContainer.querySelectorAll('.slds-welcome-mat__tile_info-only').length).to.eql(5);
    });
    it('shows info action button and do not show checkbox', function () {
      var WelcomeMatContainer = getWelcomeMatNode(document.body).querySelector('.slds-welcome-mat');
      (0, _chai.expect)(WelcomeMatContainer.querySelector('.slds-welcome-mat__info-actions')).to.exist;
      (0, _chai.expect)(WelcomeMatContainer.querySelector('.slds-welcome-mat__info-actions button')).to.exist;
      (0, _chai.expect)(WelcomeMatContainer.querySelector('.slds-checkbox')).to.exist;
    });
  });
  describe('Splash Variant', function () {
    beforeEach(function () {
      getWelcomeMat({
        variant: 'splash',
        labels: labels,
        id: 'welcome-mat-test',
        doNotShowAgainCheckbox: _react.default.createElement(_checkbox.default, {
          assistiveText: {
            label: "Don't show this again"
          },
          labels: {
            label: "Don't show this again"
          }
        }),
        onRenderInfoActions: function onRenderInfoActions() {
          return _react.default.createElement(_button.default, {
            type: "button",
            variant: "brand",
            title: "Learn More",
            label: "Learn More"
          });
        }
      });
    });
    it('renders welcome mat', function () {
      var WelcomeMatContainer = getWelcomeMatNode(document.body).querySelector('.slds-welcome-mat');
      (0, _chai.expect)(WelcomeMatContainer).to.exist;
      (0, _chai.expect)(WelcomeMatContainer.querySelector('.slds-welcome-mat__content')).to.exist;
      (0, _chai.expect)(WelcomeMatContainer.querySelector('.slds-welcome-mat__info')).to.exist;
    });
    it('does not render any tiles', function () {
      var WelcomeMatContainer = getWelcomeMatNode(document.body).querySelector('.slds-welcome-mat');
      (0, _chai.expect)(WelcomeMatContainer.querySelector('.slds-welcome-mat__tiles')).to.not.exist;
    });
    it('shows info action button and do not show checkbox', function () {
      var WelcomeMatContainer = getWelcomeMatNode(document.body).querySelector('.slds-welcome-mat');
      (0, _chai.expect)(WelcomeMatContainer.querySelector('.slds-welcome-mat__info-actions')).to.exist;
      (0, _chai.expect)(WelcomeMatContainer.querySelector('.slds-welcome-mat__info-actions button')).to.exist;
      (0, _chai.expect)(WelcomeMatContainer.querySelector('.slds-checkbox')).to.exist;
    });
  });
  describe('Trailhead Variant', function () {
    beforeEach(function () {
      getWelcomeMat({
        variant: 'trailhead-connected',
        labels: labels,
        children: tiles,
        infoBadge: _react.default.createElement(_infoBadge.default, {
          image: "/assets/images/welcome-mat/trailhead_badge@2x.png",
          onCompleteRenderActions: function onCompleteRenderActions() {
            return _react.default.createElement(_react.default.Fragment, null, _react.default.createElement("p", null, "Cha-ching! You earned the badge."), _react.default.createElement(_button.default, {
              className: "slds-m-top_medium",
              type: "button",
              variant: "brand",
              title: "View on your Trailblazer Profile",
              label: "View on your Trailblazer Profile"
            }));
          }
        }, _react.default.createElement("p", null, _react.default.createElement("strong", null, "Lightning Explorer"))),
        id: 'welcome-mat-test'
      });
    });
    it('renders welcome mat', function () {
      var WelcomeMatContainer = getWelcomeMatNode(document.body).querySelector('.slds-welcome-mat');
      (0, _chai.expect)(WelcomeMatContainer).to.exist;
      (0, _chai.expect)(WelcomeMatContainer.querySelector('.slds-welcome-mat__content')).to.exist;
      (0, _chai.expect)(WelcomeMatContainer.querySelector('.slds-welcome-mat__info')).to.exist;
      (0, _chai.expect)(WelcomeMatContainer.querySelector('.slds-welcome-mat__tiles')).to.exist;

      _reactDom.default.unmountComponentAtNode(container);

      (0, _chai.expect)(WelcomeMatContainer.querySelector('.slds-welcome-mat__tiles').childElementCount).to.eql(5);
      (0, _chai.expect)(WelcomeMatContainer.querySelectorAll('.slds-welcome-mat__tile_complete').length).to.eql(2);
    });
    it('shows trailhead badge', function () {
      var WelcomeMatInfo = getWelcomeMatNode(document.body).querySelector('.slds-welcome-mat__info');
      (0, _chai.expect)(WelcomeMatInfo.querySelector('.slds-welcome-mat__info-badge')).to.exist;
      (0, _chai.expect)(WelcomeMatInfo.querySelector('.slds-welcome-mat__info-progress p strong').textContent).to.eql('Lightning Explorer');
    });
    it('shows labels correctly', function () {
      var WelcomeMatInfo = getWelcomeMatNode(document.body).querySelector('.slds-welcome-mat__info');
      (0, _chai.expect)(WelcomeMatInfo.querySelector('.slds-welcome-mat__info-title').textContent).to.eql(title);
      (0, _chai.expect)(WelcomeMatInfo.querySelector('.slds-welcome-mat__info-description').textContent).to.eql(description);
    });
  });
});